print.sae_ml_linear: A Helper Function to Display sae_ml_linear Results, Including...

View source: R/sae_ml_linear.R

print.sae_ml_linearR Documentation

A Helper Function to Display sae_ml_linear Results, Including the Model Formula, Estimator Type, Number of Domains, and a Preview of Domain-Level Estimates

Description

This helper function displays the model formula, estimator type, number of domains, and a preview of the domain-level estimates produced by sae_ml_linear().

Usage

## S3 method for class 'sae_ml_linear'
print(x, n = 6L, ...)

Arguments

x

Object of class "sae_ml_linear".

n

Number of rows to display.

...

Further arguments.

Value

Invisibly returns x.


saeproj.multilevel documentation built on Sept. 8, 2026, 1:10 a.m.