saeml_modelsvy: An Example Small-Survey Dataset for Fitting the Linear...

saeml_modelsvyR Documentation

An Example Small-Survey Dataset for Fitting the Linear Multilevel Regression Model

Description

A simulated small-survey dataset used to demonstrate projection-based small area estimation with a linear multilevel regression model.

The dataset is one fixed replication from the simulation design used in the package examples. It contains the target variable and auxiliary variables, and is intended to be used as data_model in sae_ml_linear().

Usage

saeml_modelsvy

Format

A data frame with 250 rows, 11 variables, and 50 domains.

prov

Province identifier.

kab_kota

District or city identifier used as the domain variable.

id_individu

Unique sampled-unit identifier. It is not a PSU or cluster identifier.

Z1

First area-level auxiliary variable.

Z2

Second area-level auxiliary variable.

X1

First unit-level auxiliary variable.

X2

Binary unit-level auxiliary variable.

X3

Third unit-level auxiliary variable.

X4

Fourth unit-level auxiliary variable.

Y

Target variable.

WEIND

Survey sampling weight.

Details

Simulated model-survey data for saeproj.multilevel.

The dataset contains five sampled units in each of 50 domains. The target variable Y was generated from a random-intercept multilevel population model.

It is designed to be used together with saeml_projsvy.

The simulated survey design does not include a separate PSU or cluster identifier. Therefore, package examples use cluster_ids = ~1.

Simulated data generated from the package study-simulation design.

See Also

saeml_projsvy and sae_ml_linear.

Examples

data(saeml_modelsvy)

dim(saeml_modelsvy)
head(saeml_modelsvy)
table(saeml_modelsvy$kab_kota)

saeproj.multilevel documentation built on Sept. 8, 2026, 1:10 a.m.