summary.sae_ml_linear: A Helper Function to Display a Summary of sae_ml_linear...

View source: R/sae_ml_linear.R

summary.sae_ml_linearR Documentation

A Helper Function to Display a Summary of sae_ml_linear Results, Including the Model Specification, Estimator Type, Number of Domains, Model Diagnostics, and a Preview of Domain-Level Estimates

Description

This helper function displays the model specification, estimator type, number of domains, model diagnostics, and a preview of the domain-level estimates produced by sae_ml_linear(). The model diagnostics include the number of observations, residual standard deviation, intraclass correlation coefficient (ICC), singular fit status, and convergence status.

Usage

## S3 method for class 'sae_ml_linear'
summary(object, n = 6L, ...)

Arguments

object

Object of class "sae_ml_linear".

n

Number of rows to display.

...

Further arguments.

Value

Invisibly returns object.


saeproj.multilevel documentation built on Sept. 8, 2026, 1:10 a.m.