View source: R/sae_ml_linear.R
| print.sae_ml_linear | R Documentation |
This helper function displays the model formula, estimator type,
number of domains, and a preview of the domain-level estimates produced by
sae_ml_linear().
## S3 method for class 'sae_ml_linear'
print(x, n = 6L, ...)
x |
Object of class |
n |
Number of rows to display. |
... |
Further arguments. |
Invisibly returns x.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.