| saeml_modelsvy | R Documentation |
A simulated small-survey dataset used to demonstrate projection-based small area estimation with a linear multilevel regression model.
The dataset is one fixed replication from the simulation design used in the
package examples. It contains the target variable and auxiliary variables,
and is intended to be used as data_model in sae_ml_linear().
saeml_modelsvy
A data frame with 250 rows, 11 variables, and 50 domains.
Province identifier.
District or city identifier used as the domain variable.
Unique sampled-unit identifier. It is not a PSU or cluster identifier.
First area-level auxiliary variable.
Second area-level auxiliary variable.
First unit-level auxiliary variable.
Binary unit-level auxiliary variable.
Third unit-level auxiliary variable.
Fourth unit-level auxiliary variable.
Target variable.
Survey sampling weight.
Simulated model-survey data for saeproj.multilevel.
The dataset contains five sampled units in each of 50 domains. The target
variable Y was generated from a random-intercept multilevel
population model.
It is designed to be used together with saeml_projsvy.
The simulated survey design does not include a separate PSU or cluster
identifier. Therefore, package examples use cluster_ids = ~1.
Simulated data generated from the package study-simulation design.
saeml_projsvy and sae_ml_linear.
data(saeml_modelsvy)
dim(saeml_modelsvy)
head(saeml_modelsvy)
table(saeml_modelsvy$kab_kota)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.