| saeml_projsvy | R Documentation |
A simulated large-survey dataset used to demonstrate projection-based small area estimation with a linear multilevel regression model.
The dataset is one fixed replication from the simulation design used in the package examples. It contains auxiliary variables and survey design variables, but does not contain the target variable.
It is intended to be used as data_proj in sae_ml_linear().
saeml_projsvy
A data frame with 15,000 rows, 10 variables, and 50 domains.
Province identifier.
District or city identifier used as the domain variable.
Unique sampled-unit identifier. It is not a PSU or cluster identifier.
First area-level auxiliary variable.
Second area-level auxiliary variable.
First unit-level auxiliary variable.
Binary unit-level auxiliary variable.
Third unit-level auxiliary variable.
Fourth unit-level auxiliary variable.
Survey sampling weight.
Simulated projection-survey data for saeproj.multilevel.
The dataset contains 300 sampled units in each of 50 domains. It is drawn
from the same fixed simulated population as saeml_modelsvy, but does
not contain the target variable Y.
It is used to generate unit-level predictions and domain-level synthetic estimates.
The simulated survey design does not include a separate PSU or cluster
identifier. Therefore, package examples use cluster_ids = ~1.
Simulated data generated from the package study-simulation design.
saeml_modelsvy and sae_ml_linear.
data(saeml_projsvy)
dim(saeml_projsvy)
head(saeml_projsvy)
table(saeml_projsvy$kab_kota)
"Y" %in% names(saeml_projsvy)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.