View source: R/sae_ml_linear.R
| summary.sae_ml_linear | R Documentation |
This helper function displays the model specification, estimator type,
number of domains, model diagnostics, and a preview of the domain-level
estimates produced by sae_ml_linear(). The model diagnostics include
the number of observations, residual standard deviation, intraclass
correlation coefficient (ICC), singular fit status, and convergence status.
## S3 method for class 'sae_ml_linear'
summary(object, n = 6L, ...)
object |
Object of class |
n |
Number of rows to display. |
... |
Further arguments. |
Invisibly returns object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.